

package com.fiorano.esb.service.filenamedconfig;

import com.fiorano.edbc.framework.service.AbstractInmemoryService;
import com.fiorano.edbc.framework.service.jms.IJMSObjects;
import com.fiorano.esb.service.filenamedconfig.model.FileNamedConfigPM;
import com.fiorano.services.common.configuration.NamedConfigConstants;

/**
 * Execution class for FileNamedConfig.
 * This class contains the main method which launches the component when started as an external process.
 * It creates the JMSHandler and new configuration object if needed.
 *
 * @author Fiorano Software Technologies Pvt. Ltd.
 */
public class FileNamedConfig extends AbstractInmemoryService {

    /**
     * Creates the service instance.
     */
    public FileNamedConfig() {
    }


    /**
     * Creates a JMS Handler
     * @return JMSObjects class which handles the jmsObjects.
     */
    protected IJMSObjects _createJMSObjects() {
        return new JMSObjects(this);
    }

    /**
     * Specifies whether the configuration is mandaory or not.
     * @return whether the configuration is mandatory.
     */
    protected boolean isConfigurationMandatory() {
        return true;
    }

    /**
     * Creates a new Property Model object
     */
    protected void createDefaultServiceConfiguration() {
        configuration = new FileNamedConfigPM();
    }



    /**
     * Main method starts the service in external process.
     *
     * @param args commandline arguments
     */
    public static void main(String args[]) {
        try {
            FileNamedConfig service = new FileNamedConfig();
            service.start(args);
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    @Override
    protected void updateNamedConfigurations() throws Exception {

        FileNamedConfigPM config = (FileNamedConfigPM) getConfiguration();

        if (config == null) {
            return;
        }

        updateNamedConfiguration(config.getFileConfiguration(), NamedConfigConstants.RESOURCE_CONFIG_TYPE);
    }
}